import QtQuick 2.0

Rectangle {
	id: dive
	color: "black"

	// some important concept properties
	property alias flick: flick
	property alias anim: anim
	property var container: null
	property var pressedElement: null

	// place the dive contents in a flick area
	Flickable {
		id: flick
		width: parent.width
		height: parent.height
		contentWidth: parent.width
		contentHeight: parent.height * 1.5

		// a swipe area inside the flick area
		SwipeArea {
			id: swipe
			width: parent.width
			height: parent.height

			// slot for left/right swipe
			onSwipe: {
				pressedElement = null;
				if (!container)
					return;

				switch (direction) {
				case swipe._DIRECTION_LEFT:
					container.navigate(container._DIRECTION_LEFT);
					break;
				case swipe._DIRECTION_RIGHT:
					container.navigate(container._DIRECTION_RIGHT);
					break;
				}
			}

			/* this slot handles child element clicks (no multitouch!).
			 * the way it work is the following: child mouse areas need
			 * to register the pressed state, but not accept it. then
			 * in the swipe area itself we look for the clicked singal
			 * and if a 'pressedElement' is still focused we emit it's clicked()
			 * signal.
			 */
			onClicked: {
				if (pressedElement && pressedElement.containsMouse)
					pressedElement.clicked(mouse);
				pressedElement = null;
			}

			/* some 'dive' aware details. this can be any class, but for
			 * clicks to work inside the class, MouseAreas need to update
			 * the Dive 'pressedElement' property
			 */
			DiveDetails {
				id: diveDetails
				width: parent.width
				height: parent.height
				dive: dive
			}
		}

		// cancel pressed elements when a flick starts
		onFlickStarted: {
			console.log("flick");
			pressedElement = null;
		}
	}

	// x animation
	NumberAnimation {
		id: anim
		target: dive
		properties: "x"
		duration: 300
		easing.type: Easing.OutQuad
	}

	function fillDive() {
		diveDetails.fillDive();
	}

	Component.onCompleted: {
		fillDive();
	}
}
