import QtQuick 2.0

Rectangle {
	// some demo related properties
	property string color1: "white"
	property string color2: "black"
	property string title: "no-text"
	property string diveDetails: "no-text"

	// constants
	readonly property int fontSize: 24
	readonly property int pad: width * 0.04
	readonly property int shadowOffset: width * 0.005

	// the parent dive
	property var dive: null

	// a background to fill the entire flick and swipe area
	Rectangle {
		width: parent.width
		height: parent.height
		gradient: Gradient {
			GradientStop { position: 0.0; color: color1}
			GradientStop { position: 1.0; color: color2 }
		}
	}

	// dive title shadow (quick and dirty)
	Text {
		x: pad
		y: pad
		id: titleTextShadow
		text: title
		color: "black"
		font.pointSize: fontSize
		opacity: 0.9
	}

	// dive title
	Text {
		id: titleText
		x: titleTextShadow.x - shadowOffset
		y: titleTextShadow.y - shadowOffset
		text: title
		color: "white"
		font.pointSize: fontSize
	}

	// rect for the dive details
	Rectangle {
		id: diveDetailsRect
		x: pad
		y: titleText.y + titleText.height + pad
		width: parent.width - pad * 2
		height: dive.height / 2
		opacity: 0.9
		color: "white"
		border.color: "black"
		border.width: 1
	}

	// dive details text
	Text {
		id: diveDetailsText
		anchors.margins: pad
		anchors.fill: diveDetailsRect
		text: diveDetails
		color: "black"
		font.pointSize: fontSize

		// dive details click
		MouseArea {
			id: diveDetailsMouseArea
			anchors.fill: parent
			// -----------------------------------------------------------------
			// to make clicks work!
			propagateComposedEvents: true
			onPressed: {
				if (dive)
					dive.pressedElement = this;
				mouse.accepted = false;
			}
			onClicked: console.log("dive details clicked");
			// -----------------------------------------------------------------
		}
	}

	// profile image
	Image {
		id: profile
		x: pad
		y: diveDetailsRect.y + diveDetailsRect.height + pad
		width: parent.width - pad * 2
		height: dive.height - profile.y - pad
		source: "profile.png"

		// profile click
		MouseArea {
			id: profileMouseArea
			anchors.fill: parent
			propagateComposedEvents: true
			onPressed: {
				if (dive)
					dive.pressedElement = this;
				mouse.accepted = false;
			}
			onClicked: console.log("profile clicked");
		}
	}

	// some random contents for the dive

	function randomTitle() {
		return "Dive #" + Math.floor(Math.random() * 100000);
	}

	function randomColor() {
		return "#" + Math.floor(Math.random() * 0xffffff).toString(16);
	}

	function randomDiveDetails() {
		var buddy = ["Linus", "Tomaz", "Dirk", "Miika", "Anton", "Robert"];
		var location = ["Finland", "Sweden", "Australia", "Germany", "Brazil", "Canada", "Norway"];
		var cyl = ["AL40", "AL50", "AL63", "AL72", "AL80", "AL100"];
		var weather = ["Cold", "Warm", "Hot", "Moist"];
		var rating = ["★☆☆☆☆", "★★☆☆☆", "★★★☆☆", "★★★★☆", "★★★★★"];
		var str = "";
		str += "Buddy: " + buddy[Math.floor(Math.random() * buddy.length)] + "\n";
		str += "Location: " + location[Math.floor(Math.random() * location.length)] + "\n";
		str += "Cyl: " + cyl[Math.floor(Math.random() * cyl.length)] + "\n";
		str += "Weather: " + weather[Math.floor(Math.random() * weather.length)] + "\n";
		str += "Rating: " + rating[Math.floor(Math.random() * rating.length)] + "\n";
		return str;
	}

	function fillDive() {
		color1 = randomColor();
		color2 = randomColor();
		title = randomTitle();
		diveDetails = randomDiveDetails();
	}
}
