import QtQuick 2.0

Rectangle {
	id: page
	width: 480
	height: 800
	color: "black"

	// a dive container instance
	DiveContainer {
		id: container
		width: parent.width
		height: parent.height

		/* a navigate() callback for 2 dives.
		 * in one sentance: the current dive moves away, while the new
		 * dive is placed at the correct initial position and moves in.
		 */
		function navigate(direction)
		{
			// set temporary variables
			var diveOld, diveNew;
			if (container.currentDive == 0) {
				diveOld = dive0;
				diveNew = dive1;
				container.currentDive = 1;
			} else {
				diveOld = dive1;
				diveNew = dive0;
				container.currentDive = 0;
			}

			// check direction
			switch (direction) {
			case container._DIRECTION_LEFT:
				diveOld.x = 0;
				diveOld.anim.to = -page.width;
				diveNew.x = page.width;
				diveNew.anim.to = 0;
				break;
			case container._DIRECTION_RIGHT:
				diveOld.x = 0;
				diveOld.anim.to = page.width;
				diveNew.x = -page.width;
				diveNew.anim.to = 0;
				break;
			}

			/* stop the flick in old dive and reset the flcik position
			 * of the new dive */
			diveOld.flick.cancelFlick();
			diveNew.flick.contentY = 0;

			// fill content in the new dive
			diveNew.fillDive();

			// start the animation
			diveOld.anim.start();
			diveNew.anim.start();
		}

		/* a couple of dives that are aware of 'container' and have
		 * some paginated X positions. */

		Dive {
			id: dive0
			x: 0
			width: parent.width
			height: parent.height
			container: container
		}

		Dive {
			id: dive1
			x: parent.width
			width: parent.width
			height: parent.height
			container: container
		}
	}
}
