import QtQuick 2.0

MouseArea {
	id: swipeArea

	// prevent stealing
	preventStealing: false

	// minimul velocity to trigger a swipe
	property real minVelocity: 15.0

	/* travel distance from an edge to register a swipe [0.0, 1.0];
	 * set to 0.0 to disable. */
	property real edgeOffset: 0.0

	// private properties
	property point prevLoc
	property point startLoc
	property real veloX: 0.0
	property real veloY: 0.0
	property bool tracking: false

	// enumeration of one of the possible directions
	readonly property int _DIRECTION_LEFT: 0
	readonly property int _DIRECTION_UP: 1
	readonly property int _DIRECTION_RIGHT: 2
	readonly property int _DIRECTION_DOWN: 3

	// this signal is emitted when a swipe gesture is detected
	signal swipe(int direction)

	onPressed: {
		// clamp the edge offset to [0.0, 1.0]
		if (edgeOffset > 1.0) edgeOffset = 1.0;
		if (edgeOffset < 0.0) edgeOffset = 0.0;
		// set tracking, start location and reset velocity
		prevLoc.x = startLoc.x = mouse.x;
		prevLoc.y = startLoc.y = mouse.y;
		veloX = veloY = 0.0;
		tracking = true;
	}

	onReleased:	{
		tracking = false;
	}

	onPositionChanged: {
		if (!tracking)
			return;

		// calculate edge offset and velocity
		var edgeOffsetInv = 1.0 - edgeOffset
		var currVeloX = mouse.x - prevLoc.x;
		var currVeloY = mouse.y - prevLoc.y;
		veloX = (veloX + currVeloX) * 0.5;
		veloY = (veloY + currVeloY) * 0.5;
		prevLoc.x = mouse.x;
		prevLoc.y = mouse.y;

		// if the velocity and edgeOffset are reached dispatch a swipe() signal
		if (veloX > minVelocity && mouse.x > swipeArea.width * edgeOffset) {
			tracking = false;
			swipeArea.swipe(_DIRECTION_RIGHT)
		} else if (veloX < -minVelocity && mouse.x < swipeArea.width * edgeOffsetInv) {
			tracking = false;
			swipeArea.swipe(_DIRECTION_LEFT)
		} else if (veloY > minVelocity && mouse.y > swipeArea.height * edgeOffset) {
			tracking = false;
			swipeArea.swipe(_DIRECTION_DOWN)
		} else if (veloY < -minVelocity && mouse.y < swipeArea.height * edgeOffsetInv) {
			tracking = false;
			swipeArea.swipe(_DIRECTION_UP)
		}
	}
}
